local ldb = LibStub("LibDataBroker-1.1", true)
local hasLdb = false
if ldb and ldb:GetDataObjectByName("MobNotes") then hasLdb = true end

local frame = CreateFrame("Frame", nil, InterfaceOptionsFramePanelContainer)
frame.name = "MobNotes"
frame:Hide()

local db = nil

local function newCheckbox(label, keyOrFunc)
	local check = CreateFrame("CheckButton", "MobNotesCheck" .. label, frame, "InterfaceOptionsCheckButtonTemplate")
	if type(keyOrFunc) == "string" then
		check:SetChecked(db[keyOrFunc])
		check.setFunc = function(setting)
			db[keyOrFunc] = setting == "1" and true or false
		end
	else
		check.setFunc = keyOrFunc
	end
	_G[check:GetName() .. "Text"]:SetText(label)
	return check
end

frame:SetScript("OnShow", function(frame)
	db = MobNotesConfig
	if not db then error("MobNotes config DB is not available.") end

	local title = frame:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
	title:SetPoint("TOPLEFT", 16, -16)
	title:SetText("MobNotes")

	local subtitle = frame:CreateFontString(nil, "ARTWORK", "GameFontHighlightSmall")
	subtitle:SetPoint("TOPLEFT", title, "BOTTOMLEFT", 0, -8)
	subtitle:SetWidth(frame:GetWidth() - 40)
	subtitle:SetJustifyH("LEFT")
	subtitle:SetJustifyV("TOP")
	subtitle:SetText("MobNotes lets you set custom notes on any player or NPC ingame. If you want to contribute notes or translations then please contact me on IRC or e-mail.")
	
	local showId = newCheckbox("Unique ID in unit tooltips", "showId")
	showId:SetPoint("TOPLEFT", subtitle, "BOTTOMLEFT", -2, -12)

	local icon = LibStub("LibDBIcon-1.0", true)
	local minimap
	if icon then
		minimap = newCheckbox(
			"Minimap icon",
			function(setting)
				db.hide = setting == "0" and true or false
				if db.hide then
					icon:Hide("MobNotes")
				else
					icon:Show("MobNotes")
				end
			end)
		minimap:SetPoint("TOPLEFT", showId, "BOTTOMLEFT", 0, -8)
		minimap:SetChecked(not db.hide)
	end

	if hasLdb then
		local onText = newCheckbox("Target note on LDB text", "ldbNoteOnText")
		onText:SetPoint("TOPLEFT", minimap or showId, "BOTTOMLEFT", 0, -8)

		local onTip = newCheckbox("Target note on LDB tooltip", "ldbNoteOnTip")
		onTip:SetPoint("TOPLEFT", onText, "BOTTOMLEFT", 0, -8)
	end

	frame:SetScript("OnShow", nil)
end)
InterfaceOptions_AddCategory(frame)

